@@ -27,7 +27,7 @@
  */
 /* }}} */
 /* {{{ [fold] Includes */
-#include <linux/config.h>
+#include <linux/autoconf.h>
 #include <linux/version.h>
 
 #ifdef CONFIG_SMP
