@@ -332,21 +332,18 @@ static int vv6450_init(struct quickcam *qc)
 	if (PARANOID && !qc) { PDEBUG("qc==NULL"); return -EINVAL; }
 
 	for (i=0; i<SIZE(stv_init); i++) {
-		if (stv_init[i].data==NULL) {
-		  if(stv_init[i].len & 0xFF00) {
-		    //STV_SETW_CHECK(stv_init[i].start, stv_init[i].len);
-		    if ((r = qc_stv_setw(qc,(stv_init[i].start),(stv_init[i].len)))<0)
-		    {
-		      PDEBUG("qc_stv_setw: error");
-		    }
-		  } else {
-		    STV_SET_CHECK(stv_init[i].start, stv_init[i].len);
-		  }
-		} else {
-			for (j=0; j<stv_init[i].len; j++) {
-				STV_SET_CHECK(stv_init[i].start+j, stv_init[i].data[j]);
-			}
-		}
+	  if (stv_init[i].data==NULL) {
+	    if(stv_init[i].len & 0xFF00) {
+	      if ((r = qc_stv_setw(qc,(stv_init[i].start), cpu_to_le16(stv_init[i].len)))<0)
+		PDEBUG("qc_stv_setw: error");
+	    } else {
+	      STV_SET_CHECK(stv_init[i].start, stv_init[i].len);
+	    }
+	  } else {
+	    for (j=0; j<stv_init[i].len; j++) {
+	      STV_SET_CHECK(stv_init[i].start+j, stv_init[i].data[j]);
+	    }
+	  }
 	}
 
 	
@@ -604,7 +601,7 @@ const struct qc_sensor qc_sensor_vv6450 = {
 	/* Identification information used for auto-detection */
 	id_reg:		VV6450_DEVICEH,
 	/*
-	  0x08F0 & 0x08F5 is known to be Messenger
+	  0x08F0, 0x08F5, 0x08F6 is known to be Messenger
 	*/
 	id:		0x08,
 	length_id:	2,
