@@ -375,8 +375,8 @@ unsigned int pnm_readnum(void) {
 	return val;
 }
 /* }}} */
-/* {{{ [fold] void pnm_open(unsigned char *name, unsigned int *width, unsigned int *height) */
-void pnm_open(unsigned char *name, unsigned int *width, unsigned int *height) {
+/* {{{ [fold] void pnm_open(char *name, unsigned int *width, unsigned int *height) */
+void pnm_open(char *name, unsigned int *width, unsigned int *height) {
 	char c1,c2,c3;
 	unsigned int maxval;
 
@@ -491,7 +491,9 @@ int main(int argc, char *argv[])
 			device = argv[0];
 			fd = 0;
 		} else {
-			if (fd==0) {
+			if (fd==0
+			    && (argv[0][0]!='-' && argv[0][1]!='G')
+			    ) {
 				/* Open the device, if it wasn't yet opened.
 				 * Do not try to modify any settings, because if other applications have
 				 * already the camera open and are capturing, it might disturb them under 2.6.x */
@@ -663,6 +665,52 @@ int main(int argc, char *argv[])
 					argv += c;
 					break;
 				}
+				case 'G': {
+				  struct qc_userlut userlut;
+				  double gr = 0.55;
+				  double gg = 0.55;
+				  double gb = 0.55;
+				  double wr = 1.0;
+				  double wg = 1.0;
+				  double wb = 1.0;
+				  if(!argp) error("Missing r:g:b:r:g:b options");
+				  
+				  memset(&userlut, 0, sizeof(userlut));
+				  r = sscanf(argp, "%lg:%lg:%lg:%lg:%lg:%lg", &gr, &gg, &gb, &wr, &wg, &wb);
+				  if (r!=1 && r!=3 && r!=6) error("bad number of arguments for -G (must be 1, 3, or 6)");
+				  if (r < 3) {
+				    gg = gr;
+				    gb = gr;
+				  }
+				  for (i=0; i<256; i++) {
+				    userlut.lut[QC_LUT_RED   + i] = (unsigned char)CLIP(pow(i/256.0, gr)*256.0*wr+0.5, 0.0, 255.0);
+				    userlut.lut[QC_LUT_GREEN + i] = (unsigned char)CLIP(pow(i/256.0, gg)*256.0*wg+0.5, 0.0, 255.0);
+				    userlut.lut[QC_LUT_BLUE  + i] = (unsigned char)CLIP(pow(i/256.0, gb)*256.0*wb+0.5, 0.0, 255.0);
+				  }
+				  
+				  printf("Software lookup-table status: %s\n", (userlut.flags & QC_USERLUT_ENABLE) ? "Enabled" : "Disabled");
+				  printf("static unsigned char userlut_contents[QC_LUT_SIZE] = {\n/* Red */\n");
+				  for (i=0; i<256; i++) {
+				    printf("%4i,", userlut.lut[QC_LUT_RED + i]);
+				    if (((i+1) % 12)==0) printf("\n");
+				    if (i==255) printf("\n");
+				  }
+				  printf("/* Green */\n");
+				  for (i=0; i<256; i++) {
+				    printf("%4i,", userlut.lut[QC_LUT_GREEN + i]);
+				    if (((i+1) % 12)==0) printf("\n");
+				    if (i==255) printf("\n");
+				  }
+				  printf("/* Blue */\n");
+				  for (i=0; i<256; i++) {
+				    printf("%4i", userlut.lut[QC_LUT_BLUE + i]);
+				    if (i!=255) printf(",");
+				    if (((i+1) % 12)==0) printf("\n");
+				    //if (i==255) printf("\n");
+				  }
+				  printf("\n};\n");
+				  exit(0);
+				}
 				default:
 					error("invalid option");
 				}
