@@ -90,8 +90,12 @@ struct qc_userlut {
 
 #ifdef __KERNEL__
 
-#include <linux/config.h>
 #include <linux/version.h>
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,19)
+#include <linux/autoconf.h>
+#else
+#include <linux/config.h>
+#endif
 
 #ifdef CONFIG_SMP
 #define __SMP__
@@ -107,6 +111,9 @@ struct qc_userlut {
 #endif
 
 #include <linux/videodev.h>
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,18)
+#include <media/v4l2-common.h>
+#endif
 #include <linux/usb.h>
 #include <asm/pgtable.h>		/* This is required for testing pte_offset_map */
 #include <linux/spinlock.h>
@@ -126,16 +133,13 @@ struct qc_userlut {
 
 
 /* {{{ [fold] SECTION: user configuration */
-#define VERSION		"QuickCam Messenger/Communicate USB $Date: 2004/12/30 10:00:00 $"
+#define VERSION		"QuickCam Messenger/Communicate USB 1.8 $Date: 2008/05/26 00:00:00 $"
 #ifndef COMPRESS
 #define COMPRESS	0		/* 1=include compression support, 0=otherwise */
 #endif
 #ifndef DEBUGLEVEL
-//#define DEBUGLEVEL	0
-//#define DEBUGLEVEL	(QC_DEBUGERRORS|QC_DEBUGADAPTATION)
-//#define DEBUGLEVEL	(QC_DEBUGERRORS|QC_DEBUGUSER)
+//#define DEBUGLEVEL	QC_DEBUGCOMMON
 #define DEBUGLEVEL	(QC_DEBUGERRORS)
-//#define DEBUGLEVEL	(0xFFFF)
 #endif
 #ifdef NDEBUG				/* Enable debugging if DEBUG is defined; if (also) NDEBUG is defined, disable debugging */
 #undef DEBUG
@@ -281,7 +285,7 @@ static inline struct urb *qc_usb_alloc_urb(int packets) { return usb_alloc_urb(p
 	do {						\
 		struct timeval __tv_val;		\
 		do_gettimeofday(&__tv_val);		\
-		printk(KERN_DEBUG "quickcam [%2ld.%06ld]: ", __tv_val.tv_sec%60, __tv_val.tv_usec);	\
+		printk(KERN_DEBUG "qcmessenger [%2ld.%06ld]: ", __tv_val.tv_sec%60, __tv_val.tv_usec);	\
 		printk(fmt, ## args); 			\
 		printk("\n"); 				\
 	} while(0)
@@ -355,8 +359,8 @@ static inline struct urb *qc_usb_alloc_urb(int packets) { return usb_alloc_urb(p
 #endif /* DEBUG */
 
 //gcc is buggy? This doesn't work
-//#define PRINTK(lvl, fmt, args...)	printk(lvl "quickcam: " fmt "\n", ## args)
-#define PRINTK(lvl, fmt, args...)	do { printk(lvl "quickcam: " fmt, ## args); printk("\n"); } while (0)
+//#define PRINTK(lvl, fmt, args...)	printk(lvl "qcmessenger: " fmt "\n", ## args)
+#define PRINTK(lvl, fmt, args...)	do { printk(lvl "qcmessenger: " fmt, ## args); printk("\n"); } while (0)
 /* }}} */
 /* {{{ [fold] SECTION: hardware related stuff */
 #define QUICKCAM_ISOPIPE 	0x81
@@ -615,14 +619,9 @@ struct qc_sensor {
 /* {{{ [fold] SECTION: function prototypes */
 /* USB interface chip control */
 int qc_i2c_wait(struct quickcam *qc);
-#if 0
-int qc_i2c_break(struct quickcam *qc);
-int qc_i2c_set(struct quickcam *qc, unsigned char reg, unsigned char val);
-int qc_i2c_setw(struct quickcam *qc, unsigned char reg, unsigned short val);
-#endif
 int qc_stv_set(struct quickcam *qc, unsigned short reg, unsigned char val);
 int qc_stv_setw(struct quickcam *qc, unsigned short reg, unsigned short val);
-int qc_stv_get(struct quickcam *qc, unsigned short reg);
+int qc_stv_get(struct quickcam *qc, unsigned short reg, unsigned char *val);
 
 /* Image format conversion routines */
 int qc_fmt_convert(struct quickcam *qc, unsigned char *src, unsigned int src_len, unsigned char *dst, unsigned int dst_len, int *midvalue);
